﻿using System;
using System.Collections.Generic;

namespace TCPEssentials.DataTools
{
	public class BATools
	{
		/// <summary>
		/// Combine the given byte arrays.
		/// </summary>
		/// <param name="data">The byte arrays to combine.</param>
		/// <returns>Returns the combined byte array.</returns>
		public static byte[] Combine(List<byte[]> data)
		{
			List<byte> ByteList = new List<byte>();

			foreach (byte[] Array in data)
			{
				foreach (byte B in Array)
				{
					ByteList.Add(B);
				}
			}

			byte[] Result = new byte[ByteList.Count];

			for (int i = 0; i < ByteList.Count; i++)
			{
				Result[i] = ByteList[i];
			}

			return Result;
		}

		/// <summary>
		/// Split a byte array into pieces.
		/// </summary>
		/// <param name="data">The byte array to split.</param>
		/// <param name="pieceSize">The size of the pieces.</param>
		/// <returns>Returns the pieces of the byte array.</returns>
		public static List<byte[]> Split(byte[] data, int pieceSize)
		{
			List<List<byte>> SplitBytes = new List<List<byte>>();
			int TimeToSplit = data.Length / pieceSize;

			if (data.Length % pieceSize != 0)
			{
				TimeToSplit++;
			}

			for (int i = 0; i < TimeToSplit; i++)
			{
				SplitBytes.Add(new List<byte>());
				for (int j = 0; j < pieceSize; j++)
				{
					if (i * pieceSize + j >= data.Length)
					{
						break;
					}
					SplitBytes[i].Add(data[i * pieceSize + j]);
				}
			}

			List<byte[]> ReturnData = new List<byte[]>();
			foreach (List<byte> B in SplitBytes)
			{
				ReturnData.Add(B.ToArray());
			}

			return ReturnData;
		}

		/// <summary>
		/// Show a byte array in a string.
		/// </summary>
		/// <param name="data">The data to show as a string.</param>
		/// <returns>Returns the string representation.</returns>
		public static string ToReadableString(byte[] data)
		{
			string ReturnValue = "";
			foreach (byte B in data)
			{
				ReturnValue += " " + B;
			}

			return ReturnValue.Substring(1);
		}
	}
}
