﻿using System;
using System.Net;
using System.Net.Sockets;

namespace TCPEssentials.Networking
{
    public class TCPConnection
    {
		public string ClientIP { get; private set; }

		TcpClient TClient;
		TcpListener TListener;
		NetworkStream ConStream;
		string IP;
		int Port;

		/// <summary>
		/// Start a new TCP connection.
		/// </summary>
		/// <param name="ip">The IP to connect to, or the client IP.</param>
		/// <param name="port">The port to communicate on.</param>
		/// <param name="isListeningForRequests">True for if you're listening for requests, false if you are connecting to another IP</param>
		public TCPConnection(string ip, int port, bool isListeningForRequests)
		{
			IP = ip;
			Port = port;
			if (isListeningForRequests)
			{
				TListener = new TcpListener(IPAddress.Parse(ip), port);
				TListener.Start();
				TClient = TListener.AcceptTcpClient();
				TListener.Stop();
				ConStream = TClient.GetStream();
				ClientIP = ((IPEndPoint)TClient.Client.RemoteEndPoint).Address.ToString();
			}
			else
			{
				TClient = new TcpClient(ip, port);
				ConStream = TClient.GetStream();
				ClientIP = ip;
			}
		}

		public byte[] GetData()
		{
			byte[] DataReceived = new byte[TClient.ReceiveBufferSize];
			int ByteCount = ConStream.Read(DataReceived, 0, System.Convert.ToInt32(TClient.ReceiveBufferSize));
			byte[] Data = new byte[ByteCount];
			Array.Copy(DataReceived, Data, ByteCount);
			return Data;
		}

		/// <summary>
		/// Send data through the TCP connection.
		/// </summary>
		/// <param name="data">The data to send.</param>
		public void SendData(byte[] data)
		{
			ConStream.Write(data, 0, data.Length);
			ConStream.Flush();
		}

		/// <summary>
		/// Send data through the TCP connection.
		/// </summary>
		/// <param name="data">The data to send.</param>
		/// <param name="byteStartingIndex">The location where to start writing data.</param>
		/// <param name="length">The length of data you want to send.</param>
		public void SendData(byte[] data, int byteStartingIndex, int length)
		{
			ConStream.Write(data, byteStartingIndex, length);
		}

		/// <summary>
		/// Close the TCP connection.
		/// </summary>
		public void Close()
		{
			ConStream.Dispose();
			TClient.Close();
		}
    }
}
